pub struct DebugInfoHandler { /* private fields */ }Expand description
Debug info handler
Implementations
Sourceimpl DebugInfoHandler
impl DebugInfoHandler
Sourcepub fn new(client: RestClient) -> Self
pub fn new(client: RestClient) -> Self
Create a new handler bound to the given REST client.
Sourcepub async fn create(
&self,
_request: DebugInfoRequest,
) -> Result<DebugInfoStatus>
👎Deprecated: use the documented cluster, node, or database debuginfo methods
pub async fn create( &self, _request: DebugInfoRequest, ) -> Result<DebugInfoStatus>
use the documented cluster, node, or database debuginfo methods
Retired task-style debug info creation helper.
Sourcepub async fn status(&self, _task_id: &str) -> Result<DebugInfoStatus>
👎Deprecated: Redis Software does not register task-style debuginfo routes
pub async fn status(&self, _task_id: &str) -> Result<DebugInfoStatus>
Redis Software does not register task-style debuginfo routes
Retired task-style debug info status helper.
Sourcepub async fn list(&self) -> Result<Vec<DebugInfoStatus>>
👎Deprecated: Redis Software does not register task-style debuginfo routes
pub async fn list(&self) -> Result<Vec<DebugInfoStatus>>
Redis Software does not register task-style debuginfo routes
Retired task-style debug info list helper.
Sourcepub async fn download(&self, _task_id: &str) -> Result<Vec<u8>>
👎Deprecated: use the documented cluster, node, or database debuginfo methods
pub async fn download(&self, _task_id: &str) -> Result<Vec<u8>>
use the documented cluster, node, or database debuginfo methods
Retired task-style debug info download helper.
Sourcepub async fn cancel(&self, _task_id: &str) -> Result<()>
👎Deprecated: Redis Software does not register task-style debuginfo routes
pub async fn cancel(&self, _task_id: &str) -> Result<()>
Redis Software does not register task-style debuginfo routes
Retired task-style debug info cancellation helper.
Sourcepub async fn all(&self) -> Result<Value>
pub async fn all(&self) -> Result<Value>
Get all debug info across nodes - GET /v1/debuginfo/all (DEPRECATED) Use cluster_debuginfo_binary() for the new endpoint
Sourcepub async fn all_bdb(&self, bdb_uid: u32) -> Result<Value>
pub async fn all_bdb(&self, bdb_uid: u32) -> Result<Value>
Get all debug info for a specific database - GET /v1/debuginfo/all/bdb/{uid} (DEPRECATED) Use database_debuginfo_binary() for the new endpoint
Sourcepub async fn node(&self) -> Result<Value>
pub async fn node(&self) -> Result<Value>
Get node debug info - GET /v1/debuginfo/node (DEPRECATED) Use nodes_debuginfo_binary() for the new endpoint
Sourcepub async fn node_bdb(&self, bdb_uid: u32) -> Result<Value>
pub async fn node_bdb(&self, bdb_uid: u32) -> Result<Value>
Get node debug info for a specific database - GET /v1/debuginfo/node/bdb/{uid} (DEPRECATED) Use database_debuginfo_binary() for the new endpoint
Sourcepub async fn cluster_debuginfo_binary(&self) -> Result<Vec<u8>>
pub async fn cluster_debuginfo_binary(&self) -> Result<Vec<u8>>
Get cluster debug info package as binary - GET /v1/cluster/debuginfo Returns a tar.gz file containing all cluster debug information
Sourcepub async fn nodes_debuginfo_binary(&self) -> Result<Vec<u8>>
pub async fn nodes_debuginfo_binary(&self) -> Result<Vec<u8>>
Get all nodes debug info package as binary - GET /v1/nodes/debuginfo Returns a tar.gz file containing debug information from all nodes
Sourcepub async fn node_debuginfo_binary(&self, node_uid: u32) -> Result<Vec<u8>>
pub async fn node_debuginfo_binary(&self, node_uid: u32) -> Result<Vec<u8>>
Get specific node debug info package as binary - GET /v1/nodes/{uid}/debuginfo Returns a tar.gz file containing debug information from a specific node
Sourcepub async fn databases_debuginfo_binary(&self) -> Result<Vec<u8>>
pub async fn databases_debuginfo_binary(&self) -> Result<Vec<u8>>
Get all databases debug info package as binary - GET /v1/bdbs/debuginfo Returns a tar.gz file containing debug information from all databases
Sourcepub async fn database_debuginfo_binary(&self, bdb_uid: u32) -> Result<Vec<u8>>
pub async fn database_debuginfo_binary(&self, bdb_uid: u32) -> Result<Vec<u8>>
Get specific database debug info package as binary - GET /v1/bdbs/{uid}/debuginfo Returns a tar.gz file containing debug information from a specific database
Sourcepub async fn all_binary(&self) -> Result<Vec<u8>>
pub async fn all_binary(&self) -> Result<Vec<u8>>
Get all debug info as binary - GET /v1/debuginfo/all (DEPRECATED) Returns a tar.gz file - Use cluster_debuginfo_binary() instead
Sourcepub async fn all_bdb_binary(&self, bdb_uid: u32) -> Result<Vec<u8>>
pub async fn all_bdb_binary(&self, bdb_uid: u32) -> Result<Vec<u8>>
Get all debug info for a specific database as binary - GET /v1/debuginfo/all/bdb/{uid} (DEPRECATED) Returns a tar.gz file - Use database_debuginfo_binary() instead
Sourcepub async fn node_binary(&self) -> Result<Vec<u8>>
pub async fn node_binary(&self) -> Result<Vec<u8>>
Get node debug info as binary - GET /v1/debuginfo/node (DEPRECATED) Returns a tar.gz file - Use nodes_debuginfo_binary() instead